mkv

package
v0.0.0-...-c79eb96 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2021 License: GPL-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package mkv provides a convenience interface to mkvtoolnix command line tools.

This package only parses the minimum fields necessary for eac3to-wrapper.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Info

type Info struct {
	Version int `json:"identification_format_version"`
	Errors  []string
	Tracks  []*Track
}

Info represent a info for a mkv file. It is populated by parsing the output of `mkvmerge -J file.mkv`.

func ParseInfo

func ParseInfo(b []byte) (*Info, error)

type Track

type Track struct {
	Id    int    // the track Id property, not necessarily related to its physical id.
	Type_ string `json:"type"` // "video"/"audio"/"subtitles"

	TrackProperty `json:"properties"`
}

A Track represents a track in a MKV segment.

func (*Track) GoString

func (t *Track) GoString() string

func (*Track) Type

func (t *Track) Type() TrackType

type TrackProperty

type TrackProperty struct {
	Number int
}

type TrackType

type TrackType int8

TrackType represents the type of a track: video/audio or subtitle.

const (
	TrackTypeUnknown TrackType = iota
	TrackTypeVideo
	TrackTypeAudio
	TrackTypeSubtitle
)

Jump to