Documentation
¶
Overview ¶
Package mkv provides a convenience interface to mkvtoolnix command line tools.
This package only parses the minimum fields necessary for eac3to-wrapper.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Info ¶
type Info struct {
Version int `json:"identification_format_version"`
Errors []string
Tracks []*Track
}
Info represent a info for a mkv file. It is populated by parsing the output of `mkvmerge -J file.mkv`.
type Track ¶
type Track struct {
Id int // the track Id property, not necessarily related to its physical id.
Type_ string `json:"type"` // "video"/"audio"/"subtitles"
TrackProperty `json:"properties"`
}
A Track represents a track in a MKV segment.
type TrackProperty ¶
type TrackProperty struct {
Number int
}
Click to show internal directories.
Click to hide internal directories.